__kupfer_name__ = _("Arxx SSH Tools - astgo")
__kupfer_actions__ = ("astgo", )
__kupfer_sources__ = ("astgo_config", )
__description__ = _("With an easy command you can open up a tabbed (gnome) terminal with multiple ssh hosts, see <https://arxx.se> for more information.")
__version__ = "0.3"
__author__ = "Johan Hyllstedt <code@arxx.se>"

import gtk
import os

from kupfer import utils
from kupfer.objects import Action, Leaf
from kupfer.obj.helplib import FilesystemWatchMixin
from kupfer.obj.grouping import ToplevelGroupingSource

class astgo_leaf(Leaf):
  def get_actions(self):
    yield astgo()

  def get_description(self):
    return _("astgo profile")

  def get_icon_name(self):
    return "applications-internet"

class astgo(Action):
  def __init__(self):
    Action.__init__(self, _("astgo"))

  def item_types(self):
    yield astgo_leaf

  def get_description(self):
    return _("Launch astgo profile.")

  def get_icon_name(self):
    return "network-server"

  def activate(self, obj):
    ## Requires astgo to be in path!
    prof_name = obj.name
    utils.spawn_async(["astgo", prof_name])

class astgo_config(ToplevelGroupingSource, FilesystemWatchMixin):
  _home = os.path.expanduser("~/")
  _astgo_config = ".astgorc"
  _config_path = os.path.join(_home, _astgo_config)

  def __init__(self, name=_("astgo config")):
    ToplevelGroupingSource.__init__(self, name, "astgo_profiles")
    self._version = 2

  def initialize(self):
    ToplevelGroupingSource.initialize(self)
    self.monitor_token = self.monitor_directories(self._home)

  def monitor_include_file(self, gfile):
    return gfile and gfile.get_basename() == self._astgo_config

  def get_items(self):
    if os.path.exists(self._config_path):
      try:
        execfile(self._config_path) ## Not optimal, but meh works like a charm + python style hosts list
      except:
        pass
      else:
        if self.config != { }:
          for k in self.config.keys():
            yield astgo_leaf(k, k)

  def get_description(self):
    return _("astgo profiles as specified in ~/.astgorc")

  def get_icon_name(self):
    return "applications-internet"

  def provides(self):
    yield astgo_leaf
